Learn R Programming

easyml (version 0.1.0)

extract_coefficients.easy_glmnet: Extract coefficients from a penalized regression model.

Description

This function wraps the procedure for extracting coefficients from a glmnet model and makes it accessible to the easyml core framework.

Usage

# S3 method for easy_glmnet
extract_coefficients(object)

Arguments

object

A list of class easy_glmnet.

Value

A data.frame, the replicated penalized regression coefficients.