Learn R Programming

easyml (version 0.1.0)

fit_model.easy_avNNet: Fit an average neural network model.

Description

This function wraps the procedure for fitting an average neural network model and makes it accessible to the easyml core framework.

Usage

# S3 method for easy_avNNet
fit_model(object)

Arguments

object

A list of class easy_avNNet.

Value

A list of class easy_avNNet.