Learn R Programming

easyml (version 0.1.0)

fit_model.easy_glmnet: Fit a penalized regression model.

Description

This function wraps the procedure for fitting a glmnet model and makes it accessible to the easyml core framework.

Usage

# S3 method for easy_glmnet
fit_model(object)

Arguments

object

A list of class easy_glmnet.

Value

A list of class easy_glmnet.