Learn R Programming

easyml (version 0.1.0)

fit_model.easy_neural_network: Fit a neural network model.

Description

This function wraps the procedure for fitting a neural network model and makes it accessible to the easyml core framework.

Usage

# S3 method for easy_neural_network
fit_model(object)

Arguments

object

A list of class easy_neural_network.

Value

A list of class easy_neural_network.