Learn R Programming

easyml (version 0.1.0)

reduce_cores: Reduce number of cores.

Description

This function takes the number of cores specified by the user and reduces it to the maximum number of cores supported by the computer.

Usage

reduce_cores(n_core, cpu_count = NULL)

Arguments

n_core

An integer vector of length one; specifies the number of cores to use for this analysis. Currently only works on Mac OSx and Unix/Linux systems. Defaults to 1L.

cpu_count

An integer vector of length one; specifies the number of cores potentially available to use for this analysis. Currently only works on Mac OSx and Unix/Linux systems. Defaults to 1L.

Value

An integer vector of length one; specifies the number of cores to use for this analysis.

See Also

Other utils: correlation_test, process_coefficients, process_variable_importances, remove_variables